@@ -6,10 +6,11 @@ import tempfile
 import pytest
 
 from zict.lmdb import LMDB
+
 from . import utils_test
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def fn():
     dirname = tempfile.mkdtemp(prefix="test_lmdb-")
     try:
